==> rviz-1.13.3.tar.gz: rviz-1.13.3/src/rviz/properties/property_tree_delegate.cpp <==
/*
 * Copyright (c) 2012, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <QAbstractItemView>

#include "rviz/properties/property.h"
#include "rviz/properties/line_edit_with_button.h"

#include "rviz/properties/property_tree_delegate.h"

namespace rviz
{

PropertyTreeDelegate::PropertyTreeDelegate( QObject* parent_object )
    : QStyledItemDelegate( parent_object )
{
}

void PropertyTreeDelegate::paint( QPainter * painter,
                                  const QStyleOptionViewItem & option,
                                  const QModelIndex & index ) const
{
  Property* prop = static_cast<Property*>( index.internalPointer() );
  if( !prop || !prop->paint( painter, option ))
  {
    QStyledItemDelegate::paint( painter, option, index );
  }
}

QWidget *PropertyTreeDelegate::createEditor( QWidget *parent,
                                             const QStyleOptionViewItem & option,
                                             const QModelIndex &index ) const
{
  Property* prop = static_cast<Property*>( index.internalPointer() );
  if( !prop || prop->getReadOnly())
  {
    return 0;
  }
  
  if( QWidget* editor = prop->createEditor( parent, option ))
  {
    return editor;
  }
  return QStyledItemDelegate::createEditor( parent, option, index );
}

} // end namespace rviz

==> rviz-1.14.4.tar.gz: rviz-1.14.4/src/rviz/properties/property_tree_delegate.cpp <==
/*
 * Copyright (c) 2012, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <QAbstractItemView>

#include <rviz/properties/property.h>
#include <rviz/properties/line_edit_with_button.h>

#include <rviz/properties/property_tree_delegate.h>

namespace rviz
{
PropertyTreeDelegate::PropertyTreeDelegate(QObject* parent_object) : QStyledItemDelegate(parent_object)
{
}

void PropertyTreeDelegate::paint(QPainter* painter,
                                 const QStyleOptionViewItem& option,
                                 const QModelIndex& index) const
{
  Property* prop = static_cast<Property*>(index.internalPointer());
  if (!prop || !prop->paint(painter, option))
  {
    QStyledItemDelegate::paint(painter, option, index);
  }
}

QWidget* PropertyTreeDelegate::createEditor(QWidget* parent,
                                            const QStyleOptionViewItem& option,
                                            const QModelIndex& index) const
{
  Property* prop = static_cast<Property*>(index.internalPointer());
  if (!prop || prop->getReadOnly())
  {
    return nullptr;
  }

  if (QWidget* editor = prop->createEditor(parent, option))
  {
    return editor;
  }
  return QStyledItemDelegate::createEditor(parent, option, index);
}

} // end namespace rviz
